;------------------------------------------------------------------------------
pro lts_planefit_example
;
; V1.0: Michele Cappellari, Oxford, 07 March 2011

ntot = 300 ; Number of values

; Coefficients of the test plane
;
a = 10d
b = 2d
c = 1d

s = 1234  ; random seed
n = ntot*0.9
x = 20 + (0.5-randomu(s,n))*5
y = 10 + (0.5-randomu(s,n))*5
z = a + b*x + c*y

sig_int = 1d ; Intrinsic scatter in z
z += randomn(s,n)*sig_int

sigx = 0.2 ; Observational error in x
sigy = 0.4 ; Observational error in y
sigz = 0.4 ; Observational error in z
x += randomn(s,n)*sigx
y += randomn(s,n)*sigy
z += randomn(s,n)*sigz

; Outliers produce a background of spurious values
; intersecting with the true distribution
;
nout = ntot*0.1 ; 10% outliers
x1 = 20 + (0.5-randomu(s,nout))*20
y1 = 30 + (0.5-randomu(s,nout))*20
z1 = max(z) - randomu(s,nout)*(max(z)-min(z))/2

; Combines the good values and the outliers in one vector
;
x = [x[*],x1[*]]
y = [y[*],y1[*]]
z = [z[*],z1[*]]

sigx = x*0d + sigx ; Adopted error in x
sigy = x*0d + sigy ; Adopted error in y
sigz = x*0d + sigz ; Adopted error in z

lts_planefit, x, y, z, sigx, sigy, sigz, abc, sig_abc, chi2, $
    /PLOT, /TEXT, /EPSZ, XTITLE='z', YTITLE=textoidl('a + b (x-x_0) + c (y-y_0)'), $
    PIVOTX=median(x), PIVOTY=median(y)

end
;------------------------------------------------------------------------------
